==> libsvgo-1.3.2-dev.0.tgz: package/plugins/reusePaths.js <==
var e=require("../lib/svgo/jsAPI")
;/**
 * @license
 * The MIT License
 *
 * Copyright © 2012–2016 Kir Belevich
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *
 * Лицензия MIT
 *
 * Copyright © 2012–2016 Кир Белевич
 *
 * Данная лицензия разрешает лицам, получившим копию
 * данного
 * программного обеспечения и сопутствующей
 * документации
 * (в дальнейшем именуемыми «Программное Обеспечение»),
 * безвозмездно
 * использовать Программное Обеспечение без
 * ограничений, включая
 * неограниченное право на использование, копирование,
 * изменение,
 * добавление, публикацию, распространение,
 * сублицензирование
 * и/или продажу копий Программного Обеспечения, также
 * как и лицам,
 * которым предоставляется данное Программное
 * Обеспечение,
 * при соблюдении следующих условий:
 *
 * Указанное выше уведомление об авторском праве и
 * данные условия
 * должны быть включены во все копии или значимые части
 * данного
 * Программного Обеспечения.
 *
 * ДАННОЕ ПРОГРАММНОЕ ОБЕСПЕЧЕНИЕ ПРЕДОСТАВЛЯЕТСЯ «КАК
 * ЕСТЬ»,
 * БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ, ЯВНО ВЫРАЖЕННЫХ ИЛИ
 * ПОДРАЗУМЕВАЕМЫХ,
 * ВКЛЮЧАЯ, НО НЕ ОГРАНИЧИВАЯСЬ ГАРАНТИЯМИ ТОВАРНОЙ
 * ПРИГОДНОСТИ,
 * СООТВЕТСТВИЯ ПО ЕГО КОНКРЕТНОМУ НАЗНАЧЕНИЮ И
 * ОТСУТСТВИЯ НАРУШЕНИЙ
 * ПРАВ. НИ В КАКОМ СЛУЧАЕ АВТОРЫ ИЛИ ПРАВООБЛАДАТЕЛИ НЕ
 * НЕСУТ
 * ОТВЕТСТВЕННОСТИ ПО ИСКАМ О ВОЗМЕЩЕНИИ УЩЕРБА, УБЫТКОВ
 * ИЛИ ДРУГИХ
 * ТРЕБОВАНИЙ ПО ДЕЙСТВУЮЩИМ КОНТРАКТАМ, ДЕЛИКТАМ ИЛИ
 * ИНОМУ,
 * ВОЗНИКШИМ ИЗ, ИМЕЮЩИМ ПРИЧИНОЙ ИЛИ СВЯЗАННЫМ С
 * ПРОГРАММНЫМ
 * ОБЕСПЕЧЕНИЕМ ИЛИ ИСПОЛЬЗОВАНИЕМ ПРОГРАММНОГО
 * ОБЕСПЕЧЕНИЯ
 * ИЛИ ИНЫМИ ДЕЙСТВИЯМИ С ПРОГРАММНЫМ ОБЕСПЕЧЕНИЕМ.
 */exports.name="reusePaths"
exports.type="full"
exports.active=!1
exports.description="Finds <path> elements with the same d, fill, and stroke, and converts them to <use> elements referencing a single <path> def."
exports.params={}
exports.fn=function(s){const r=new Map
let n=0
const l=[]
!function e(t,s){if(!t.isEmpty())for(const r of t.content){s(r)
e(r,s)}}(s,e=>{if(!e.isElem("path")||!e.hasAttr("d"))return
const s=e.attr("d").value
const o=e.hasAttr("fill")&&e.attr("fill").value||""
const a=s+";s:"+(e.hasAttr("stroke")&&e.attr("stroke").value||"")+";f:"+o
const i=r.get(a)
if(i){if(!i.reused){i.reused=!0
i.elem.hasAttr("id")||i.elem.addAttr({name:"id",local:"id",prefix:"",value:"reuse-"+n++})
l.push(i.elem)}e=t(e,i.elem.attr("id").value)}else r.set(a,{elem:e,reused:!1})})
const o=new e.JSAPI({elem:"defs",prefix:"",local:"defs",content:[],attrs:[]},s)
s.content[0].spliceContent(0,0,o)
for(let e of l){const s=e.style
const r=e.class
delete e.style
delete e.class
const n=e.clone()
e.style=s
e.class=r
n.removeAttr("transform")
o.spliceContent(0,0,n)
e=t(e,n.attr("id").value)
e.removeAttr("id")}return s}
function t(e,t){e.renameElem("use")
e.removeAttr("d")
e.removeAttr("stroke")
e.removeAttr("fill")
e.addAttr({name:"xlink:href",local:"xlink:href",prefix:"none",value:"#"+t})
delete e.pathJS
return e}

==> libsvgo-1.3.3.tgz: package/plugins/reusePaths.js <==
"use strict"
Object.defineProperty(exports,"__esModule",{value:!0})
exports.fn=exports.params=exports.description=exports.active=exports.type=exports.name=void 0
var e=require("../lib/svgo/jsAPI")

;/**
 * @license
 * The MIT License
 *
 * Copyright © 2012–2016 Kir Belevich
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *
 * Лицензия MIT
 *
 * Copyright © 2012–2016 Кир Белевич
 *
 * Данная лицензия разрешает лицам, получившим копию
 * данного
 * программного обеспечения и сопутствующей
 * документации
 * (в дальнейшем именуемыми «Программное Обеспечение»),
 * безвозмездно
 * использовать Программное Обеспечение без
 * ограничений, включая
 * неограниченное право на использование, копирование,
 * изменение,
 * добавление, публикацию, распространение,
 * сублицензирование
 * и/или продажу копий Программного Обеспечения, также
 * как и лицам,
 * которым предоставляется данное Программное
 * Обеспечение,
 * при соблюдении следующих условий:
 *
 * Указанное выше уведомление об авторском праве и
 * данные условия
 * должны быть включены во все копии или значимые части
 * данного
 * Программного Обеспечения.
 *
 * ДАННОЕ ПРОГРАММНОЕ ОБЕСПЕЧЕНИЕ ПРЕДОСТАВЛЯЕТСЯ «КАК
 * ЕСТЬ»,
 * БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ, ЯВНО ВЫРАЖЕННЫХ ИЛИ
 * ПОДРАЗУМЕВАЕМЫХ,
 * ВКЛЮЧАЯ, НО НЕ ОГРАНИЧИВАЯСЬ ГАРАНТИЯМИ ТОВАРНОЙ
 * ПРИГОДНОСТИ,
 * СООТВЕТСТВИЯ ПО ЕГО КОНКРЕТНОМУ НАЗНАЧЕНИЮ И
 * ОТСУТСТВИЯ НАРУШЕНИЙ
 * ПРАВ. НИ В КАКОМ СЛУЧАЕ АВТОРЫ ИЛИ ПРАВООБЛАДАТЕЛИ НЕ
 * НЕСУТ
 * ОТВЕТСТВЕННОСТИ ПО ИСКАМ О ВОЗМЕЩЕНИИ УЩЕРБА, УБЫТКОВ
 * ИЛИ ДРУГИХ
 * ТРЕБОВАНИЙ ПО ДЕЙСТВУЮЩИМ КОНТРАКТАМ, ДЕЛИКТАМ ИЛИ
 * ИНОМУ,
 * ВОЗНИКШИМ ИЗ, ИМЕЮЩИМ ПРИЧИНОЙ ИЛИ СВЯЗАННЫМ С
 * ПРОГРАММНЫМ
 * ОБЕСПЕЧЕНИЕМ ИЛИ ИСПОЛЬЗОВАНИЕМ ПРОГРАММНОГО
 * ОБЕСПЕЧЕНИЯ
 * ИЛИ ИНЫМИ ДЕЙСТВИЯМИ С ПРОГРАММНЫМ ОБЕСПЕЧЕНИЕМ.
 */exports.name="reusePaths"
exports.type="full"
exports.active=!1
exports.description="Finds <path> elements with the same d, fill, and stroke, and converts them to <use> elements referencing a single <path> def."
exports.params={}
exports.fn=function(r){const o=new Map
let n=0
const l=[]
s(r,(e=>{if(!e.isElem("path")||!e.hasAttr("d"))return
const s=e.attr("d").value
const r=e.hasAttr("fill")&&e.attr("fill").value||""
const a=s+";s:"+(e.hasAttr("stroke")&&e.attr("stroke").value||"")+";f:"+r
const i=o.get(a)
if(i){if(!i.reused){i.reused=!0
i.elem.hasAttr("id")||i.elem.addAttr({name:"id",local:"id",prefix:"",value:"reuse-"+n++})
l.push(i.elem)}e=t(e,i.elem.attr("id").value)}else o.set(a,{elem:e,reused:!1})}))
const a=new e.JSAPI({elem:"defs",prefix:"",local:"defs",content:[],attrs:[]},r)
r.content[0].spliceContent(0,0,a)
for(let e of l){const s=e.style
const r=e.class
delete e.style
delete e.class
const o=e.clone()
e.style=s
e.class=r
o.removeAttr("transform")
a.spliceContent(0,0,o)
e=t(e,o.attr("id").value)
e.removeAttr("id")}return r}
function t(e,t){e.renameElem("use")
e.removeAttr("d")
e.removeAttr("stroke")
e.removeAttr("fill")
e.addAttr({name:"xlink:href",local:"xlink:href",prefix:"none",value:"#"+t})
delete e.pathJS
return e}function s(e,t){if(!e.isEmpty())for(const r of e.content){t(r)
s(r,t)}}
